*********
Microsite
*********

.. contents:: Table of Contents

Life, the Universe, and Everything
----------------------------------

A very basic Dexterity-based container to be used as a microsite.

Mostly Harmless
---------------

.. image:: http://img.shields.io/pypi/v/sc.microsite.svg
    :target: https://pypi.python.org/pypi/sc.microsite

.. image:: https://img.shields.io/travis/simplesconsultoria/sc.microsite/master.svg
    :target: http://travis-ci.org/simplesconsultoria/sc.microsite

.. image:: https://img.shields.io/coveralls/simplesconsultoria/sc.microsite/master.svg
    :target: https://coveralls.io/r/simplesconsultoria/sc.microsite

Got an idea? Found a bug? Let us know by `opening a support ticket <https://github.com/simplesconsultoria/sc.microsite/issues>`_.

Don't Panic
-----------

Installation
^^^^^^^^^^^^

To enable this product in a buildout-based installation:

#. Edit your buildout.cfg and add ``sc.microsite`` to the list of eggs to install:

.. code-block:: ini

    [buildout]
    ...
    eggs =
        sc.microsite

After updating the configuration you need to run ''bin/buildout'', which will take care of updating your system.

Go to the 'Site Setup' page in a Plone site and click on the 'Add-ons' link.

Check the box next to ``sc.microsite`` and click the 'Activate' button.

Usage
^^^^^

TBA.
